@@ -1,8 +1,8 @@
 --- a/include/autoconf.hin
 +++ b/include/autoconf.hin
-@@ -892,4 +892,8 @@ Added missing headers after gettext upda
+@@ -998,4 +998,8 @@ Added missing headers after gettext upda
   */
- #	undef DISABLE_PIPELINING
+ #	undef HAVE_LIB_GNUTLS
  
 +/* debian-specific */
 +#define XFACE_ABLE
